@@ -191,9 +191,11 @@ implore; But the fact is I was napping, and so gently you came rapping, And so
 faintly you came tapping, tapping at my chamber door?
 """
 
-MODNAMES = ('clu.compilation.compiledb',
+MODNAMES = ('clu.compilation',
+            'clu.compilation.compiledb',
             'clu.compilation.macros',
             'clu.config',
+            'clu.config.abc',
             'clu.config.base',
             'clu.config.env',
             'clu.config.fieldtypes',
@@ -204,19 +206,23 @@ MODNAMES = ('clu.compilation.compiledb',
             'clu.config.formats.tomlfile',
             'clu.config.formats.yamlfile',
             'clu.config.settings',
+            'clu.constants',
             'clu.constants.enums',
             'clu.csv',
             'clu.dicts',
             'clu.enums',
             'clu.exporting',
+            'clu.fs',
             'clu.fs.appdirectories',
             'clu.fs.filesystem',
             'clu.fs.misc',
             'clu.fs.pypath',
+            'clu.fs.sourcetree',
             'clu.keyvalue',
             'clu.mathematics',
             'clu.naming',
             'clu.predicates',
+            'clu.repl',
             'clu.repl.ansi',
             'clu.repl.banners',
             'clu.repl.cli',
