@@ -57,16 +57,21 @@ metaclass = lambda thing: ismetaclass(thing) and thing \
 
 # PREDICATE FUNCTIONS: hasattr(…) shortcuts:
 
-noattr = lambda thing, atx: negate(hasattr)(thing, atx)
+noattr = negate(hasattr)
 haspyattr = lambda thing, atx: hasattr(thing, f'__{atx}__')
-nopyattr = lambda thing, atx: negate(haspyattr)(thing, atx)
+nopyattr = negate(haspyattr)
 
 anyattrs = lambda thing, *attrs: any(hasattr(thing, atx) for atx in attrs)
 allattrs = lambda thing, *attrs: all(hasattr(thing, atx) for atx in attrs)
-noattrs = lambda thing, *attrs: negate(anyattrs)(thing, *attrs)
+noattrs = negate(anyattrs)
+
 anypyattrs = lambda thing, *attrs: any(haspyattr(thing, atx) for atx in attrs)
 allpyattrs = lambda thing, *attrs: all(haspyattr(thing, atx) for atx in attrs)
-nopyattrs = lambda thing, *attrs: negate(anypyattrs)(thing, *attrs)
+nopyattrs = negate(anypyattrs)
+
+# Calling “typeof(…)” on a thing returns either its type, or – if it is
+# a classtype – the thing itself:
+typeof = lambda thing: nopyattr(thing, 'mro') and type(thing) or thing
 
 # Things with a __len__(…) method “have length”:
 haslength = lambda thing: haspyattr(thing, 'len')
@@ -74,8 +79,11 @@ haslength = lambda thing: haspyattr(thing, 'len')
 # Things with either __iter__(…) OR __getitem__(…) are iterable:
 isiterable = lambda thing: anypyattrs(thing, 'iter', 'getitem')
 
-# q.v. `merge_two(…)` implementation sub.
-ismergeable = lambda thing: bool(hasattr(thing, 'get') and isiterable(thing))
+# q.v. `merge_two(…)` implementation sub. –
+# this predicate could also be called “isgetitemable()” in terms of
+# the implementation of “getitem(…)” as below:
+ismergeable = lambda thing: isiterable(thing) and \
+                            allpyattrs(thing, 'getitem', 'contains')
 
 # ACCESSORS: getattr(…) shortcuts
 
@@ -156,7 +164,7 @@ item_across   = lambda itx, *things, default=tuple(): collator(getitem,   itx, *
 def isenum(cls):
     """ isenum(cls) → boolean predicate, True if cls descends from `Enum`. """
     from clu.constants.polyfills import Enum
-    if not isclasstype(cls):
+    if nopyattr(cls, 'mro'):
         return False
     return Enum in cls.__mro__
 
@@ -314,7 +322,7 @@ def noneof(*items):
 def slots_for(cls):
     """ slots_for(cls) → get the summation of the `__slots__` tuples for a class and its ancestors """
     # q.v. https://stackoverflow.com/a/6720815/298171
-    if not isclasstype(cls):
+    if nopyattrs(cls, 'mro', 'bases'):
         return slots_for(type(cls))
     mro = pyattr(cls, 'mro', 'bases', default=tuplize(object))
     return tuple(iterchain(
@@ -328,6 +336,7 @@ export(ismetaclass,     name='ismetaclass',     doc="ismetaclass(thing) → bool
 export(isclass,         name='isclass',         doc="isclass(thing) → boolean predicate, True if thing is a class, descending from `object` but not `type`")
 export(isclasstype,     name='isclasstype',     doc="isclasstype(thing) → boolean predicate, True if thing is a class type, descending from either `object` or `type`")
 export(metaclass,       name='metaclass',       doc="metaclass(thing) → Returns: a) thing, if thing is a metaclass; b) type(thing), if thing is a class; or c) type(type(thing)), for all other instances")
+export(typeof,          name='typeof',          doc="typeof(thing) → Returns thing, if thing is a class type; or type(thing), if it is not")
 
 export(noattr,          name='noattr',          doc="noattr(thing, attribute) → boolean predicate, shortcut for `(not hasattr(thing, attribute))`")
 export(haspyattr,       name='haspyattr',       doc="haspyattr(thing, attribute) → boolean predicate, shortcut for `hasattr(thing, '__%s__' % attribute)`")
